==> lim_cli-20.5.1-py2.py3-none-any.whl: lim/packet_cafe/admin/delete.py <==
# -*- coding: utf-8 -*-

import argparse
import logging
import textwrap

from cliff.command import Command
from lim.packet_cafe import add_packet_cafe_global_options
from lim.packet_cafe import check_remind_defaulting
from lim.packet_cafe import chose_wisely
from lim.packet_cafe import get_session_ids
from lim.packet_cafe import get_last_request_id
from lim.packet_cafe import get_last_session_id
from lim.packet_cafe import delete

logger = logging.getLogger(__name__)


class AdminDelete(Command):
    """Delete data for a session."""

    def get_parser(self, prog_name):
        parser = super().get_parser(prog_name)
        parser.formatter_class = argparse.RawDescriptionHelpFormatter
        parser.add_argument(
            '--all',
            action='store_true',
            dest='all',
            default=False,
            help=('Delete data for all sessions (careful with that '
                  'flag, Eugene!  default: False)')
        )
        parser.add_argument(
            'sess_id', nargs='*', default=[get_last_session_id()])
        parser.epilog = textwrap.dedent("""
            Deletes all data and id directories for one or more
            sessions.

            """)  # noqa
        return add_packet_cafe_global_options(parser)

    def take_action(self, parsed_args):
        logger.debug('[+] deleting session data')
        ids = get_session_ids()
        if ids is None or not len(ids):
            raise RuntimeError('No sessions exist')
        if parsed_args.all:
            sess_ids = ids
        else:
            if parsed_args.sess_id[0] is not None:
                sess_id = check_remind_defaulting(
                    parsed_args.sess_id[0], 'last session id')
            else:
                sess_id = chose_wisely(from_list=ids,
                                       what="a session",
                                       cancel_throws_exception=True)
            if sess_id not in ids:
                raise RuntimeError(f'Session ID { sess_id } not found')
            sess_ids = [sess_id]
        for sess_id in sess_ids:
            result = delete(sess_id=sess_id)
            if result is None:
                raise RuntimeError('failed to delete '
                                   f'session { sess_id }')
            # Do state files need to be deleted?
            # (Granted, this relies on a side-effect, but
            # c'est la vie. ¯\_(ツ)_/¯)
            _, _ = get_last_session_id(), get_last_request_id()
            logger.info(f'[+] deleted session { sess_id }')


# vim: set ts=4 sw=4 tw=0 et :

==> lim_cli-20.6.0-py2.py3-none-any.whl: lim/packet_cafe/admin/delete.py <==
# -*- coding: utf-8 -*-

import argparse
import logging
import textwrap

from cliff.command import Command
from lim.packet_cafe import add_packet_cafe_global_options
from lim.packet_cafe import check_remind_defaulting
from lim.packet_cafe import choose_wisely
from lim.packet_cafe import get_session_ids
from lim.packet_cafe import get_last_request_id
from lim.packet_cafe import get_last_session_id
from lim.packet_cafe import delete

logger = logging.getLogger(__name__)


class AdminDelete(Command):
    """Delete data for a session."""

    def get_parser(self, prog_name):
        parser = super().get_parser(prog_name)
        parser.formatter_class = argparse.RawDescriptionHelpFormatter
        parser.add_argument(
            '--all',
            action='store_true',
            dest='all',
            default=False,
            help=('Delete data for all sessions (careful with that '
                  'flag, Eugene!  default: False)')
        )
        parser.add_argument(
            'sess_id', nargs='*', default=[get_last_session_id()])
        parser.epilog = textwrap.dedent("""
            Deletes all data and id directories for one or more
            sessions.

            To select specific sessions, provide them as arguments.
            You can select the desired session ID from a list of
            available sessions with the ``--choose`` option, or
            delete all sessions at once with ``--all``:

            .. code-block:: console

                $ lim cafe admin delete --all
                [+] deleted session 531f8bad-1f01-4b10-926b-a72aa27bcdba
                [+] deleted session e6129371-ab97-4225-940e-5b18cd761da7
                [+] deleted session 46d4f9a9-d5db-487e-a261-91764c044b44
                [+] deleted session f44dc0e5-2ad0-4cbd-aac9-98a6c8233dff
                [+] deleted session 5382b1b3-39f2-4563-9486-8efb99b56243

            ..
            """)  # noqa
        return add_packet_cafe_global_options(parser)

    def take_action(self, parsed_args):
        logger.debug('[+] deleting session data')
        ids = get_session_ids()
        if ids is None or not len(ids):
            raise RuntimeError('[-] no sessions exist')
        if parsed_args.all:
            sess_ids = ids
        else:
            if parsed_args.sess_id[0] is not None and not parsed_args.choose:
                sess_id = check_remind_defaulting(
                    parsed_args.sess_id[0], 'last session id')
            else:
                sess_id = choose_wisely(from_list=ids,
                                        what="a session",
                                        cancel_throws_exception=True)
            if sess_id not in ids:
                raise RuntimeError(f'[-] session ID { sess_id } not found')
            sess_ids = [sess_id]
        for sess_id in sess_ids:
            result = delete(sess_id=sess_id)
            if result is None:
                raise RuntimeError('[-] failed to delete '
                                   f'session { sess_id }')
            # Do state files need to be deleted?
            # (Granted, this relies on a side-effect, but
            # c'est la vie. ¯\_(ツ)_/¯ )
            _, _ = get_last_session_id(), get_last_request_id()
            logger.info(f'[+] deleted session { sess_id }')


# vim: set ts=4 sw=4 tw=0 et :
